@@ -1,5 +1,5 @@
 import pandas as pd
-
+import numpy as np
 from hieroskopia import InferNumeric
 
 
@@ -32,12 +32,18 @@ class TestNumericAnalyser:
                                                       {'three_digit_separator': '', 'decimal_separator': '.',
                                                        'type': 'integer'},
                                                       {'three_digit_separator': ',', 'decimal_separator': '.',
-                                                       'type': 'float'}],
+                                                       'type': 'float'}, {}, {}],
                                        data={
                                            "date": ["2019-11-27",
                                                     "2019-11-28",
                                                     "2019-11-29"],
                                            "gateway": ["PROSA", "PROSA", "PROSA"],
                                            "amount": ["$4591", "$4592", "-$5"],
-                                           "order_id": ['767,313,628,196.2', '76,731,362,819', '767,313,628,196']
+                                           "order_id": ['767,313,628,196.2', '76,731,362,819', '767,313,628,196'],
+                                           "order": [
+                                               ';20200626;20201228;20210628;20211227;20220628;20221226;20230626;20231226;20240626;20241226;20250626;20251226',
+                                               ';20200626;20201228;20210628;20211227;20220628;20221226;20230626;20231226;20240626;20241226;20250626;20251226',
+                                               ';20200626;20201228;20210628;20211227;20220628;20221226;20230626;20231226;20240626;20241226;20250626;20251226'
+                                           ],
+                                           "nan": [np.nan, np.nan, np.nan]
                                        })
